@@ -18,6 +18,10 @@
 
 #include <stdint.h>
 
+#ifndef _BUILDING_LVM
+#warning "liblvm2app is deprecated, use D-Bus API instead."
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
