@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/usr/bin/env bash
 
 # Copyright (C) 2011-2014 Red Hat, Inc. All rights reserved.
 #
@@ -13,6 +13,7 @@
 # test currently needs to drop
 # 'return NULL' in _lv_create_an_lv after log_error("Can't create %s without using "
 
+
 SKIP_WITH_LVMPOLLD=1
 
 export LVM_TEST_THIN_REPAIR_CMD=${LVM_TEST_THIN_REPAIR_CMD-/bin/false}
@@ -24,7 +25,7 @@ check_lv_field_modules_()
 	mod=$1
 	shift
 
-	for d in $*; do
+	for d in "$@"; do
 		check lv_field $vg/$d modules $mod
 	done
 }
@@ -36,8 +37,9 @@ aux have_thin 1 0 0 || skip
 which mkfs.ext4 || skip
 
 aux prepare_pvs 2 64
+get_devs
 
-vgcreate $vg -s 64K $(cat DEVICES)
+vgcreate $SHARED -s 64K "$vg" "${DEVICES[@]}"
 
 # Create named pool only
 lvcreate -l1 -T $vg/pool1
